---
title: 서비스 필수 구축요건
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 서비스 필수 구축요건
  description: >-
    결제대행사(PG사)와 계약을 맺기 전 사전 준비 단계인 PG사 입점 심사와 카드사 심사 2가지의 안내입니다. 포트원에서 접수된 신청서를
    PG사로, PG사는 카드사로 전달하여 PG사에서 1번, 카드사까지 총 2번에 걸친 입점 심사를 받게 됩니다.
tags:
  - 공통
  - 결제대행사 계약
pgCompanies:
  - 공통
searchTags:
  - 계약전 준비
  - 사이트
  - PG사심사
  - PG심사
  - APK
  - 서비스준비
  - 사업자등록증
  - 미구축
  - PPT
  - 카드사심사
  - 카드사 심사
  - 가입요건
  - 사이트 기본
  - 사이트구축
  - 계약
  - 심사
  - 미비사항
  - 입점심사
  - 서비스구축
  - 기본구성
  - 구축요건
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="연동하실 PG사 심사를 위해 연동하실 사이트를 준비해 주시는 과정입니다. 웹이 아니라 앱이어도 괜찮습니다.
해당 서비스에 담긴 내용이 중요하므로 어떤 내용을 체크해야 하는지 아래 내용으로 자세히 확인해 주세요!
" title="결제대행사(PG사)와 계약을 맺기 전 반드시 먼저 준비해 주셔야 하는 단계가 있습니다." />

### **PG사 / 카드사 입점심사는 무엇일까요?**

- PG사를 통해 결제 서비스를 오픈하기 전, 고객님의 사업장에서는 총 2가지의 심사를 받게 되는데, 이것은 바로 **'PG사 입점 심사'** 와 **'카드사 심사**'입니다.
- 포트원에서 접수된 신청서를 PG사로, PG사는 카드사로 전달하여 PG사에서 1번, 카드사까지 총 2번에 걸친 입점 심사를 받게 됩니다.
- PG사 및 카드사에서는 접수된 가입 신청서를 통해 고객사의 서비스(웹사이트 또는 앱) URL에 접속하여 '판매하는 상품','판매금액','사업자 정보','환불 정책' 등의 정보를 확인합니다.
- PG사에서는  고객사의 서비스가 판매하는 상품이 <Highlight text="입점제한 업종" />에 포함되는지, 불법적인 서비스인지 등 서비스의 안정성을 파악하여 입점 여부를 결정하기 때문에 서비스(웹사이트 또는 앱)이 구축되어 있지 않다면 계약 진행 시에 입점 심사가 지연 또는 반려될 수 있습니다.

### **입점 심사를 위해 필수적으로 준비해야 하는 내용은 무엇일까요?**

1. **판매 상품(서비스) 등록**

- 실물(배송 가능한) 상품 : \
  3개 이상 세팅 필요. 상품 상세정보, 결제금액, 환불 정보, 배송/교환, 운영규정(이용약관/개인정보취급방침)
- 비실물(컨텐츠) 서비스 : \
  1개 이상 세팅 필요. 서비스 상세정보, 결제금액, 환불 정보, 운영규정(이용약관/개인정보취급방침)
- 정기결제 상품 : \
  기본 상품 정보 외, 정기결제가 필요한 상품인지 여부 체크하므로 주기적으로 일어나는 상품을 등록해 주셔야 합니다. (ex: 구독 결제, 꽃 배달, 수강료 등)
- 판매하는 서비스 상품 금액을 고정 금액(선택하여 요청하는 방식)이 아닌, 임의 입력(견적 금액 임의 입력)과 같은 형태의 서비스의 경우에는 PG사 및 카드사 입점이 어려울 수 있습니다.

<Callout content="**전자상거래 등에서의 소비자보호에 관한 법률 제13조 4항의 규정에 따르면, 통신판매업자가 소비자에게 제공(표시, 광고 또는 고지) 하여야 할 재화 등의 정보에 관한 사항과 거래 조건에 관한 정보의 내용(정확한 금액)과 제공 방법을 구체적으로 제시해야 합니다**" icon="💡" title="참고사항" />

2\. **아직 개발 중 일 때 참고사항**

- 테스트 URL(demo,dev,test,staging 등)로 심사 진행시 일부 카드사(하나카드)에서 반려될 수 있습니다.\
  때문에 이후 실 URL으로 변경 시 재심사 들어가게 되며, 재심사 기간 동안 카드 결제가 차단될 수 있으므로 실 URL으로 카드사 심사를 받으시는 것을 권장 드립니다.\
  또한 사이트 내 상품명 TEST,결제금액 0원의 경우 카드사 심사가 불가하니 참고하시어 구현 부탁 드립니다.
- 실 서비스 운영중이신 경우에는 별도 로그인 계정으로만 접속가능한 결제페이지를 구현하시거나, 서브도메인으로 심사를 진행할 수 있으니 참고 바랍니다.\
  심사를 위해 특정 계정으로 로그인했을때 만 테스트 가능한 심사 상품이 노출되도록 구현해두셔도 되며, 혹은 운영하시는 도메인 외 서브 도메인으로도 심사를 받으실 수 있습니다.\
  (단, 서브도메인은 test, staging, dev 등의 문구가 포함되면 심사가 어렵습니다)
- <Highlight text="'카드사 심사' 진행을 위해서는 결제하는 페이지 및 PG사 결제 모듈이 호출되도록 구현되어 있어야 합니다.(PG사별 테스트모드 설정 방법) " />

**3. 연동할 서비스(웹사이트 또는 모바일앱) 하단에 사업자정보 기재**

- 사업자등록증상의 정보와 일치해야하며, 메인홈페이지 외 결제페이지까지 상시 노출되어야합니다.
- 앱 서비스의 경우 모바일 하단 혹은 별도의 메뉴를 분리하여 기재해주세요.
- 필수 노출 사항: <Highlight text="상호명, 사업자등록번호, 대표자명, 사업장주소지, 전화번호(휴대폰번호 불가)" />
- 통신판매업번호 : 2021년 8월부터 일부카드사(KB국민카드)에서 카드사심사를 위해 '통신판매업번호'를 필수 기재되어야 심사진행이 가능하게 되었습니다.(통신판매업 신고를 위한 '구매안전확인증'은 신청하신 PG사에 요청하시면 발급가능합니다)

**4. 앱 서비스로 진행시**

- 물론 ‘앱 서비스’의 스토어 등록 전인 경우에도 PG계약을 진행하실 수 있습니다.
- 포트원 PG 구입 신청 시 '앱 서비스'로 체크해 주시고 추후 PG 사와 계약 진행 시 PG 계약담당자를 통해 apk 파일 및 앱 캡쳐화면(앱 내 결제 경로)을 PPT 형식으로 전달하여 심사 진행이 가능합니다. \
  (다만 PG결제창 호출 부분까지 구현이 필요합니다)
- 또한 이 경우에도 앱 내에 판매상품, 사업자정보는 반드시 기재 돼 있어야합니다.
- <Highlight text="다날 결제서비스와 ‘토스페이 간편결제’ PG사의 경우, 모바일앱으로 결제연동 시, 앱마켓(구글플레이스토어, 앱스토어) 등록은 필수입니다.(해당 PG사 내부 정책)" />



**5. 본인인증만 진행하는 경우**

- 본인확인 서비스만 신청하는 경우에는 앱스토어 등록 전 APK파일 또는 앱 심사문서 형태로 진행이 가능합니다.
- SMS 본인인증만 이용하는 경우, 서비스 소개 페이지 및 사업자 정보 노출은 필수입니다.



6\. 해외결제 서비스 심사시

- 해외결제는 기본 영문/결제통화 'USD' 구현이 필요하고 현지 결제수단(중국/일본 등)의 경우 해당 국가 언어로 구현이 필요할 수 있습니다.
